Changelog
=========

1.0.4
-----

* Tolerance for existing usernames/emails (bubenkoff)


1.0.2
-----

* Added google apps domain setting (bubenkoff)


1.0.0
-----

* Initial public release (bubenkoff)
